import { Page } from "@/pages/base";
import {
    Button,
    ButtonGroup,
    Container,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Link,
    Menu,
    MenuItem,
    TextField,
    Typography
} from "@material-ui/core";
import { Link as RouterLink, useHistory } from "react-router-dom";
import { route } from "@/routing";
import { InternshipForm } from "@/forms/internship";
import React, { useState } from "react";
import { ProposalComment } from "@/pages/steps/proposal";
import { useTranslation } from "react-i18next";
import { ProposalPreview } from "@/components/proposalPreview";
import { useSelector } from "react-redux";
import { Internship } from "@/data";
import { AppState } from "@/state/reducer";
import { internshipSerializationTransformer } from "@/serialization";
import { Actions } from "@/components";
import { InternshipProposalActions, useDispatch } from "@/state/actions";
import { MenuDown, StickerCheckOutline, StickerRemoveOutline } from "mdi-material-ui/index";
import { useVerticalSpacing } from "@/styles";
import { AcceptanceActions } from "@/components/acceptance-action";

export const InternshipProposalFormPage = () => {
    const { t } = useTranslation();

    return <Page title={ t("pages.proposal-form.header") }>
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>{ t("pages.my-internship.header") }</Link>
                <Typography color="textPrimary">{ t("pages.proposal-form.header") }</Typography>
            </Page.Breadcrumbs>
            <Page.Title>{ t("pages.proposal-form.header") }</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" }>
            <ProposalComment />
            <InternshipForm/>
        </Container>
    </Page>
}

export const InternshipProposalPreviewPage = () => {
    const { t } = useTranslation();
    const proposal = useSelector<AppState, Internship | null>(state => state.proposal.proposal && internshipSerializationTransformer.reverseTransform(state.proposal.proposal));

    const dispatch = useDispatch();
    const history = useHistory();

    const handleAccept = (comment?: string) => {
        dispatch({ type: InternshipProposalActions.Approve, comment: comment || null });
        history.push(route("home"));
    }

    const handleDiscard = (comment: string) => {
        dispatch({ type: InternshipProposalActions.Decline, comment: comment });
        history.push(route("home"));
    }

    const classes = useVerticalSpacing(3);

    return <Page title={ t("") }>
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>Moja praktyka</Link>
                <Typography color="textPrimary">Podgląd zgłoszenia</Typography>
            </Page.Breadcrumbs>
            <Page.Title>Moje zgłoszenie</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" } className={ classes.root }>
            <ProposalComment />
            { proposal && <ProposalPreview proposal={ proposal } /> }

            <Actions>
                <AcceptanceActions onAccept={ handleAccept } onDiscard={ handleDiscard } label="internship" />

                <Button component={ RouterLink } to={ route("home") }>
                    { t('go-back') }
                </Button>
            </Actions>
        </Container>
    </Page>
}

export default InternshipProposalFormPage;
